==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/src/Uncertainty/Algorithm/IsoProbabilisticTransformation/NatafEllipticalCopula/NatafEllipticalCopulaEvaluation.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  NatafEllipticalCopulaEvaluation.cxx
 *  @brief Class for the Nataf transformation evaluation for elliptical
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-10-31 11:52:04 +0100 (ven 31 oct 2008) $
 *  Id:      $Id: NatafEllipticalCopulaEvaluation.cxx 995 2008-10-31 10:52:04Z dutka $
 */
#include "OT.hxx"
#include "NatafEllipticalCopulaEvaluation.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {

      /*
       * @class NatafEllipticalCopulaEvaluation
       *
       * This class offers an interface for the Nataf function for elliptical copula
       */

      CLASSNAMEINIT(NatafEllipticalCopulaEvaluation);

      /* Parameter constructor */
      NatafEllipticalCopulaEvaluation::NatafEllipticalCopulaEvaluation(const Distribution & standardDistribution,
								       const SquareMatrix & inverseCholesky):
	NumericalMathEvaluationImplementation(),
	standardDistribution_(standardDistribution),
	inverseCholesky_(inverseCholesky)
      {
	Description description;
	for (UnsignedLong i = 0; i < inverseCholesky_.getNbColumns(); ++i)
	  {
	    OSS oss;
	    oss << "x" << i;
	    description.add(oss);
	  }
	for (UnsignedLong i = 0; i < inverseCholesky_.getNbRows(); ++i)
	  {
	    OSS oss;
	    oss << "y" << i;
	    description.add(oss);
	  }
	setDescription(description);
      }

      /* Virtual constructor */
      NatafEllipticalCopulaEvaluation * NatafEllipticalCopulaEvaluation::clone() const
      {
	return new NatafEllipticalCopulaEvaluation(*this);
      }

      /* String converter */
      String NatafEllipticalCopulaEvaluation::str() const
      {
	OSS oss;
	oss << "class=" << NatafEllipticalCopulaEvaluation::GetClassName()
	    << " description=" << getDescription()
            << " standardDistribution=" << standardDistribution_
            << " inverseCholesky=" << inverseCholesky_;
                   
	return oss;
      }

      /*
       * Evaluation
       * This function transforms an elliptical copula with correlation matrix R into the associated standard elliptical distribution:
       * Yi(x) = Q(xi), where Q = F^{-1} and F is the CDF of the standard elliptical distribution
       * T(x) = G.Y(x), where G = L^{-1} and L is the Cholesky factor of R: L.L^t = R, L is lower triangular
       */
      NatafEllipticalCopulaEvaluation::NumericalPoint NatafEllipticalCopulaEvaluation::operator () (const NumericalPoint & in) const
	throw (InvalidArgumentException, InternalException)
      {
	UnsignedLong dimension(getOutputNumericalPointDimension());
	NumericalPoint result(dimension);
	Distribution standardMarginal(standardDistribution_.getMarginal(0));
	// First, filter the commmon marginal distribution
	for (UnsignedLong i = 0; i < dimension; ++i)
	  {
	    result[i] = standardMarginal.computeQuantile(in[i])[0];
	  }
	// Second, decorrelate the components
	return inverseCholesky_ * result;
      }

      /* Gradient according to the marginal parameters. Currently, the dependence parameters are not taken into account. */

      NatafEllipticalCopulaEvaluation::Matrix NatafEllipticalCopulaEvaluation::parametersGradient(const NumericalPoint & in) const
      {
	return Matrix(0, getInputNumericalPointDimension());
      }
	  
      /* Accessor for input point dimension */
      UnsignedLong NatafEllipticalCopulaEvaluation::getInputNumericalPointDimension() const
	throw(InternalException)
      {
	return inverseCholesky_.getNbColumns();
      }

      /* Accessor for output point dimension */
      UnsignedLong NatafEllipticalCopulaEvaluation::getOutputNumericalPointDimension() const
	throw(InternalException)
      {
	return inverseCholesky_.getNbRows();
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

==> openturns_0.13.1.orig.tar.gz: openturns-0.13.1/lib/src/Uncertainty/Algorithm/IsoProbabilisticTransformation/NatafEllipticalCopula/NatafEllipticalCopulaEvaluation.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  NatafEllipticalCopulaEvaluation.cxx
 *  @brief Class for the Nataf transformation evaluation for elliptical
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009) $
 *  Id:      $Id: NatafEllipticalCopulaEvaluation.cxx 1262 2009-05-28 12:47:53Z dutka $
 */
#include "OTprivate.hxx"
#include "NatafEllipticalCopulaEvaluation.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {

      /*
       * @class NatafEllipticalCopulaEvaluation
       *
       * This class offers an interface for the Nataf function for elliptical copula
       */

      CLASSNAMEINIT(NatafEllipticalCopulaEvaluation);

      /* Parameter constructor */
      NatafEllipticalCopulaEvaluation::NatafEllipticalCopulaEvaluation(const Distribution & standardDistribution,
								       const SquareMatrix & inverseCholesky):
	NumericalMathEvaluationImplementation(),
	standardDistribution_(standardDistribution),
	inverseCholesky_(inverseCholesky)
      {
	Description description;
	for (UnsignedLong i = 0; i < inverseCholesky_.getNbColumns(); ++i)
	  {
	    OSS oss;
	    oss << "x" << i;
	    description.add(oss);
	  }
	for (UnsignedLong i = 0; i < inverseCholesky_.getNbRows(); ++i)
	  {
	    OSS oss;
	    oss << "y" << i;
	    description.add(oss);
	  }
	setDescription(description);
      }

      /* Virtual constructor */
      NatafEllipticalCopulaEvaluation * NatafEllipticalCopulaEvaluation::clone() const
      {
	return new NatafEllipticalCopulaEvaluation(*this);
      }

      /* String converter */
      String NatafEllipticalCopulaEvaluation::__repr__() const
      {
	OSS oss;
	oss << "class=" << NatafEllipticalCopulaEvaluation::GetClassName()
	    << " description=" << getDescription()
            << " standardDistribution=" << standardDistribution_
            << " inverseCholesky=" << inverseCholesky_;
                   
	return oss;
      }

      /*
       * Evaluation
       * This function transforms an elliptical copula with correlation matrix R into the associated standard elliptical distribution:
       * Yi(x) = Q(xi), where Q = F^{-1} and F is the CDF of the standard elliptical distribution
       * T(x) = G.Y(x), where G = L^{-1} and L is the Cholesky factor of R: L.L^t = R, L is lower triangular
       */
      NatafEllipticalCopulaEvaluation::NumericalPoint NatafEllipticalCopulaEvaluation::operator () (const NumericalPoint & in) const
	throw (InvalidArgumentException, InternalException)
      {
	UnsignedLong dimension(getOutputNumericalPointDimension());
	NumericalPoint result(dimension);
	Distribution standardMarginal(standardDistribution_.getMarginal(0));
	// First, filter the commmon marginal distribution
	for (UnsignedLong i = 0; i < dimension; ++i)
	  {
	    result[i] = standardMarginal.computeQuantile(in[i])[0];
	  }
	// Second, decorrelate the components
	return inverseCholesky_ * result;
      }

      /* Gradient according to the marginal parameters. Currently, the dependence parameters are not taken into account. */

      NatafEllipticalCopulaEvaluation::Matrix NatafEllipticalCopulaEvaluation::parametersGradient(const NumericalPoint & in) const
      {
	return Matrix(0, getInputNumericalPointDimension());
      }
	  
      /* Accessor for input point dimension */
      UnsignedLong NatafEllipticalCopulaEvaluation::getInputNumericalPointDimension() const
	throw(InternalException)
      {
	return inverseCholesky_.getNbColumns();
      }

      /* Accessor for output point dimension */
      UnsignedLong NatafEllipticalCopulaEvaluation::getOutputNumericalPointDimension() const
	throw(InternalException)
      {
	return inverseCholesky_.getNbRows();
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */
